import { Button, Col, message, Row } from 'antd';
import { useIntl } from 'umi';
import React from 'react';
import styles from '../../styles.module.less';

interface ButtonsProps {
  onSave?: () => Promise<boolean>;
  onNextStep: () => Promise<boolean>;
  disable: {save: boolean, nextStep: boolean};
  productId: number | string | false;
  isNewProduct: boolean;
  step: number;
  onNextText?: string
}

const Buttons: React.FC<ButtonsProps> = ({
  disable,
  onSave,
  onNextStep,
  isNewProduct,
  onNextText,
  step
}) => {
  const intl = useIntl();
  return (
    <Row style={{ width: '100%', padding: '10px 0' }} justify={'end'}>
      {onSave ? (
        <Col style={{ marginRight: '10px' }}>
          <Button
            className={styles.saveBtn}
            disabled={disable.save}
            onClick={async () => {
              const success = await onSave();
              let messageText = '';
              if(isNewProduct) messageText = intl.formatMessage({id: 'product.theProductDraftHasBeenSaved'})
              else messageText = intl.formatMessage({id: 'product.theProductDraftHasBeenSaved'})
              if (success) message.success(messageText);
            }}
          >
            {intl.formatMessage({ id: 'product.save' })}
          </Button>
        </Col>
      ) : null}
      <Col>
        <Button
          className={disable ? styles.saveBtn : styles.nextBtn}
          disabled={disable.nextStep}
          onClick={async ()=> {
            const success = await onNextStep();
            let messageText = '';
            if(isNewProduct) messageText = intl.formatMessage({id: 'product.theProductDraftHasBeenSavedAutomatically'})
            else messageText = intl.formatMessage({id: 'product.theProductDraftHasBeenSavedAutomatically'})
            if(step === 3){
              messageText = isNewProduct ?  intl.formatMessage({ id: 'product.newProductHasBeenCreated' }) : intl.formatMessage({ id: 'product.aProductHasBeenSaved' });
            }
            if (success && !disable.save) message.success(messageText);
          }}
        >
          {onNextText || intl.formatMessage({ id: 'product.nextStep' })}
        </Button>
      </Col>
    </Row>
  );
};

export default Buttons;
